/*
 * @author lsy
 * @date   2020/7/4
 **/
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_common/commonModel/picker/base/BaseBottomPicker.dart';
import 'package:gm_flutter/ClueModel/page/DiscussLowPrice/DiscussLowPricePopView.dart';
import 'package:gm_flutter/ClueModel/page/levelOne/LevelOneListModel.dart';
import 'package:gm_flutter/ClueModel/page/mechanismBox/MechanismBoxPage.dart';
import 'package:gm_flutter/ClueModel/server/entity/LevelOneFeedList.dart';
import 'package:gm_flutter/commonModel/App.dart';
import 'package:gm_flutter/commonModel/base/BaseComponent.dart';
import 'package:gm_flutter/commonModel/bean/Pair.dart';
import 'package:gm_flutter/commonModel/cache/CacheManager.dart';
import 'package:gm_flutter/commonModel/eventbus/SimpleEventBus.dart';
import 'package:gm_flutter/main.mark.dart';
import 'package:pull_to_refresh/pull_to_refresh.dart';

import 'LevelOneItem.dart';

class LevelOneList extends StatefulWidget {
  double topHeight;
  int planId;
  String tabName;
  String pageName;
  int index;

  LevelOneList(
      this.index, this.pageName, this.planId, this.tabName, this.topHeight);

  @override
  State<StatefulWidget> createState() => LevelOneListState();
}

class LevelOneListState extends State<LevelOneList>
    with AutomaticKeepAliveClientMixin {
  LevelOneListModel _model = LevelOneListModel();
  RefreshController refreshController = RefreshController();

  Function(String str) refresh;

  @override
  void initState() {
    super.initState();
    _model.plan_id = widget.planId;
    _model.tab_type = widget.tabName;
    _model.refreshView(true);
    refresh = (str) {
      _model.stateLive.notifyView(LOADING);
      _model.refreshView(true);
    };
    SimpleEventBus.instance().resignEvent("LevelOneList", refresh);
  }

  @override
  void dispose() {
    refreshController.dispose();
    _model.dispose();
    SimpleEventBus.instance().unResignEvent("LevelOneList", refresh);
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    super.build(context);
    return baseStateView(MediaQuery.of(context).size.width,
        MediaQuery.of(context).size.height, _model.stateLive, pages(), () {
      _model.stateLive.notifyView(LOADING);
      _model.refreshView(true);
    }, paddingTop: widget.topHeight);
  }

  Widget pages() {
    return baseRefreshView(refreshController, () {}, null, null,
        customScrollView: CustomScrollView(
//          physics: NeverScrollableScrollPhysics(),
          physics: ClampingScrollPhysics(),
//          shrinkWrap: true,
          slivers: <Widget>[
//            SliverOverlapInjector(
//              handle: NestedScrollView.sliverOverlapAbsorberHandleFor(context),
//            ),
            StreamBuilder<List<Cards>>(
              stream: _model.cardsLive.stream,
              initialData: _model.cardsLive.data ?? [],
              builder: (c, data) {
                if (data.data.isEmpty && _model.page > 1) {
                  refreshController.loadNoData();
                } else {
                  refreshController.loadComplete();
                }
                return SliverList(
                  delegate: SliverChildBuilderDelegate(
                    (BuildContext context, int index) {
                      if (index == _model.data.length) {
                        return Container(
                          height: 40,
                          color: Color(0xffF7F6FA),
                        );
                      }
                      return LevelOneItem(
                        _model.data[index],
                        lowPrice: () {
                          if (CacheManager.getInstance()
                                      .get(MEMORY_CACHE)
                                      .get(USER_ID) ==
                                  null &&
                              RouterCenterImpl()
                                  .findMainRouter()
                                  .isWithNative()) {
                            RouterCenterImpl()
                                .findMainRouter()
                                .jumpPage(context, "show_login", null, true);
                            return;
                          }

                          var data2 = _model.data[index];
                          if (data2.cardType == "doctor") {
                            buried_on_click_button(index, "bargain", "doctor",
                                data2.doctor.doctor_id);
                          } else if (data2.cardType == "hospital") {
                            buried_on_click_button(index, "bargain", "hospital",
                                data2.hospital.hosiptalId);
                          } else if (data2.cardType == "plan") {
                            buried_on_click_button(index, "bargain",
                                "level_two_plan", "${data2.plan.plan_id}");
                          }
                          DiscussLowPricePopView.showPopView(
                              context,
                              widget.pageName,
                              "${widget.planId}",
                              _model.data[index].cardType == "hospital"
                                  ? _model.data[index].hospital.hosiptalId
                                  : "",
                              _model.data[index].cardType == "doctor"
                                  ? _model.data[index].doctor.doctor_id
                                  : "");
                        },
                        ask: () {
                          var data2 = _model.data[index];
                          if (data2.cardType == "doctor") {
                            buried_on_click_button(index, "consult", "doctor",
                                data2.doctor.doctor_id);
                            RouterCenterImpl().findMainRouter().jumpPage(
                                context, data2.doctor.messageUrl, null, true);
                          } else if (data2.cardType == "hospital") {
                            buried_on_click_button(index, "consult", "hospital",
                                data2.hospital.hosiptalId);
                            RouterCenterImpl().findMainRouter().jumpPage(
                                context, data2.hospital.messageUrl, null, true);
                          } else if (data2.cardType == "plan") {
                            buried_on_click_button(index, "consult",
                                "level_two_plan", "${data2.plan.plan_id}");
                            BaseBottomPicker()
                              ..setPicker(MechanismBox(data2.plan.plan_id))
                              ..show(context);
                          }
                        },
                        compare: (int planId) {
                          var data2 = _model.data[index];
                          if (data2.cardType == "doctor") {
                            buried_on_click_button(index, "compare", "doctor",
                                data2.doctor.doctor_id);
                          } else if (data2.cardType == "hospital") {
                            buried_on_click_button(index, "compare", "hospital",
                                data2.hospital.hosiptalId);
                          } else if (data2.cardType == "plan") {
                            buried_on_click_button(index, "compare",
                                "level_two_plan", "${data2.plan.plan_id}");
                          }

                          Map<String, dynamic> map = {
                            "business_id": "${widget.planId}",
                            "planId": planId,
                            "planType": 2
                          };
                          RouterCenterImpl().findMainRouter().jumpPage(
                              context,
                              widget.index == 0
                                  ? "level_one_plan_compare"
                                  : "level_two_plan_compare",
                              {"planId": planId, "planType": 2},
                              false);
                        },
                        tabName: _model.tab_type,
                        position: index,
                      );
                    },
                    childCount: _model.data.length + 1,
                  ),
                );
              },
            ),
            StreamBuilder<List<Cards>>(
              stream: _model.cardsLive.stream,
              initialData: _model.data ?? [],
              builder: (c, data) {
                double totalHeight = 0;
                _model.data.forEach((element) {
                  totalHeight += LevelOneItem.getCardTypeHeight(element);
                });
                double height = MediaQuery.of(context).size.height -
                        40 -
                        widget.topHeight -
                        totalHeight
//                    - 55
//                    - 40
                    ;
                return SliverToBoxAdapter(
                  child: Container(
                    color: Color(0xffF7F6FA),
                    height: height < 0 ? 0 : height,
                  ),
                );
              },
            ),
          ],
        ), onLoading: () {
      _model.loadMore();
    }, pullDown: false, pullUp: true, loadMoreColor: Color(0xffF7F6FA));
  }

  buried_on_click_button(
      int position, String btnName, String cardContentType, String cardId) {
    Map<String, dynamic> buriedMap;
    buriedMap = {
      "tab_name": _model.tab_type,
      "position": position,
      "card_id": cardId,
      "button_name": btnName,
      "card_type": "card",
      "transaction_type": "",
      "card_content_type": cardContentType
    };
    RouterCenterImpl()
        .findMainRouter()
        .buriedEvent("on_click_button", buriedMap);
  }

  @override
  bool get wantKeepAlive => true;
}
